@@ -72,13 +72,28 @@ pref("mailnews.headers.showUserAgent",       false);
 // is displayed in the message pane or not...
 pref("mailnews.headers.showOrganization",    false);
 
+// space-delimited list of extra headers to show in msg header display area.
+pref("mailnews.headers.extraExpandedHeaders", "");
+
 // If true, delete will use the direction of the sort order
 // in determining the next message to select. 
 pref("mail.delete_matches_sort_order", false);
 
+// default sort order settings (when creating new folder views)
+// sort_order is an int value reflecting nsMsgViewSortOrder values
+//   as defined in nsIMsgDBView.idl (ascending = 1, descending = 2)
+// sort_type is an int value reflecting nsMsgViewSortType values
+//   as defined in nsIMsgDBView.idl (byDate = 18, byThread = 22 etc.)
+pref("mailnews.default_sort_order", 1); // for Mail/RSS/... (nsMsgDatabase)
+pref("mailnews.default_sort_type", 18); //
+pref("mailnews.default_news_sort_order", 1); // for News (nsNewsDatabase)
+pref("mailnews.default_news_sort_type", 22); //
+
 // mailnews tcp read+write timeout in seconds.
 pref("mailnews.tcptimeout", 60);
 
+pref("mailnews.headers.showSender", false);
+
 // Mail server preferences, pop by default
 pref("mail.server_type",	0); 	// 0 pop, 1 imap,
 					// (Unix only:)
@@ -118,6 +133,10 @@ pref("mail.imap.mime_parts_on_demand_threshold", 30000);
 pref("mail.imap.use_literal_plus",          true);
 pref("mail.imap.expunge_after_delete",      false);
 pref("mail.imap.check_deleted_before_expunge", false);
+// if true, we assume that a user access a folder in the other users namespace
+// is acting as a delegate for that folder, and wishes to use the other users
+// identity when acting on messages in other users folders.
+pref("mail.imap.delegateOtherUsersFolders", false);
 pref("mail.thread_without_re",	            true);  // if false, only thread by subject if Re:
 pref("mail.strict_threading",               false); // if true, don't thread by suject at all
 pref("mail.leave_on_server",                false);
@@ -144,18 +163,22 @@ pref("mail.use_fcc",                        true);
 pref("mail.cc_self",                        false);
 pref("mail.strictly_mime",                  false);
 pref("mail.strictly_mime_headers",          true);
-pref("mail.strictly_mime.parm_folding",     2);  // 0/1 (RFC 2047), 2(RFC 2231)
+// 0/1 (RFC 2047), 2(RFC 2231), 3/4(RFC 2231, but name param is encoded by RFC 2047)
+// 0/3 the name param is never separated to multiple lines.
+pref("mail.strictly_mime.parm_folding",     3);  
 pref("mail.label_ascii_only_mail_as_us_ascii", false); 
 pref("mail.file_attach_binary",             false);
 pref("mail.show_headers",                   1); // some
 pref("mail.pane_config",                    0);
 pref("mail.addr_book.mapit_url.format", "chrome://messenger-region/locale/region.properties");
-//@line 154 "/mozdisk/11bbuild/mozilla/mailnews/mailnews.js"
+//@line 175 "/mozdisk/112build/mozilla/mailnews/mailnews.js"
+pref("mailnews.start_page.url", "chrome://messenger-region/locale/region.properties");
 pref("mail.addr_book.im.onlineCheckAllowed", false);
 pref("messenger.throbber.url","chrome://messenger-region/locale/region.properties");
 pref("compose.throbber.url","chrome://messenger-region/locale/region.properties");
 pref("addressbook.throbber.url","chrome://messenger-region/locale/region.properties");
-//@line 159 "/mozdisk/11bbuild/mozilla/mailnews/mailnews.js"
+pref("mail.accountwizard.deferstorage", false);
+//@line 182 "/mozdisk/112build/mozilla/mailnews/mailnews.js"
 
 // the format for "mail.addr_book.quicksearchquery.format" is:
 // @V == the escaped value typed in the quick search bar in the addressbook
@@ -232,7 +255,7 @@ pref("mailnews.offline_sync_mail",         false);
 pref("mailnews.offline_sync_news",         false);
 pref("mailnews.offline_sync_send_unsent",  true);
 pref("mailnews.offline_sync_work_offline", false);   
-pref("mailnews.force_ascii_search",         false);
+pref("mailnews.force_ascii_search",        false);
 
 pref("mailnews.send_default_charset",       "chrome://messenger/locale/messenger.properties");
 pref("mailnews.view_default_charset",       "chrome://messenger/locale/messenger.properties");
@@ -249,6 +272,7 @@ pref("mailnews.quotingPrefs.version",       0);  // used to decide whether to mi
 // the first time, we'll warn the user about the blind send, and they can disable the warning if they want.
 pref("mapi.blind-send.enabled",             true);  
 
+pref("offline.autoDetect",                  false); // automatically move the user offline or online based on the network connection
 pref("offline.news.download.unread_only",   true);
 pref("offline.news.download.by_date",       true);
 pref("offline.news.download.days",          30);    // days
@@ -324,8 +348,8 @@ pref("ldap_2.servers.default.attrmap.HomeZipCode", "mozillaHomePostalCode");
 pref("ldap_2.servers.default.attrmap.WorkCountry", "c,countryname");
 pref("ldap_2.servers.default.attrmap.HomeCountry", "mozillaHomeCountryName");
 pref("ldap_2.servers.default.attrmap.JobTitle", "title");
-pref("ldap_2.servers.default.attrmap.Department", "department,departmentnumber,ou,orgunit");
-pref("ldap_2.servers.default.attrmap.Company", "company,o");
+pref("ldap_2.servers.default.attrmap.Department", "ou,department,departmentnumber,orgunit");
+pref("ldap_2.servers.default.attrmap.Company", "o,company");
 pref("ldap_2.servers.default.attrmap._AimScreenName", "nsAIMid,nscpaimscreenname");
 pref("ldap_2.servers.default.attrmap.WebPage1", "mozillaWorkUrl,workurl");
 pref("ldap_2.servers.default.attrmap.WebPage2", "mozillaHomeUrl,homeurl");
@@ -364,13 +388,13 @@ pref("ldap_2.prefs_migrated",      false);
 
 pref("mailnews.confirm.moveFoldersToTrash", true);
 
+// space-delimited list of extra headers to add to .msf file
 pref("mailnews.customDBHeaders", "");
 
 pref("mailnews.reuse_message_window", true);
 pref("mailnews.reuse_thread_window2", false);
 pref("mailnews.open_window_warning", 10); // warn user if they attempt to open more than this many messages at once
 
-pref("mailnews.start_page.url", "chrome://messenger-region/locale/region.properties");
 pref("mailnews.start_page.enabled", true);
 
 pref("mailnews.remember_selected_message", true);
@@ -555,8 +579,29 @@ pref("mailnews.html_domains","");
 pref("mailnews.plaintext_domains","");
 pref("mailnews.global_html_domains.version",1);
 
+/////////////////////////////////////////////////////////////////
+// Privacy Controls for Handling Remote Content
+///////////////////////////////////////////////////////////////// 
+pref("mailnews.message_display.allow.plugins", false); // disable plugins by default
+pref("mailnews.message_display.disable_remote_image", true);
+
+/////////////////////////////////////////////////////////////////
+// Trusted Mail Domains
+//
+// Specific domains can be white listed to bypass various privacy controls in Thunderbird
+// such as blocking remote images, the phishing detector, etc. This is particularly
+// useful for business deployments where images or links reference servers inside a 
+// corporate intranet. For multiple domains, separate them with a comma. i.e.
+// pref("mail.trusteddomains", "mozilla.org,mozillafoundation.org");
+///////////////////////////////////////////////////////////////// 
+pref("mail.trusteddomains", "");
+
 pref("mail.imap.use_status_for_biff", true);
 
+pref("mail.quota.mainwindow_threshold.show", 75); // in percent. when the quota meter starts showing up at all. decrease this for it to be more than a warning.
+pref("mail.quota.mainwindow_threshold.warning", 80); // when it gets yellow
+pref("mail.quota.mainwindow_threshold.critical", 95); // when it gets red
+
 // Pref controlling confirmation of folder deletion on empty trash
 pref("mail.imap.confirm_emptyTrashFolderDeletion", false);
 // Pref controlling the updates on the pre-configured accounts.
@@ -648,12 +693,6 @@ pref("mailnews.customHeaders", "");
 pref("mailnews.fakeaccount.show", false);
 pref("mailnews.fakeaccount.server", "");
 
-// message display properties
-pref("mailnews.message_display.allow.plugins", false);
-pref("mailnews.message_display.disable_remote_image", true);
-pref("mailnews.message_display.disable_remote_images.useWhitelist", true);
-pref("mailnews.message_display.disable_remote_images.whiteListAbURI","moz-abmdbdirectory://abook.mab");
-
 // default msg compose font prefs
 pref("msgcompose.font_face",                "");
 pref("msgcompose.font_size",                "medium");
@@ -664,6 +703,10 @@ pref("msgcompose.background_color",         "#FFFFFF");
 // to prevent some mail server to disclose the bcc recipients
 pref("mail.compose.add_undisclosed_recipients", true);
 
+// Set this preference to true to tell mail not to attach the source of a link to a local
+// network file (file://///<network name>/<path>/<file name>). Windows only
+pref("mail.compose.dont_attach_source_of_local_network_links", false);
+
 // these prefs (in minutes) are here to help QA test this feature
 // "mail.purge.min_delay", never purge a junk folder more than once every 480 minutes (60 mins/hour * 8 hours)
 // "mail.purge.timer_interval", fire the purge timer every 5 minutes, starting 5 minutes after we load accounts
@@ -684,9 +727,9 @@ pref("mail.standalone", false);
 // the users last used preference.
 pref("mailnews.import.text.skipfirstrecord", true);
 
-//@line 694 "/mozdisk/11bbuild/mozilla/mailnews/mailnews.js"
+//@line 737 "/mozdisk/112build/mozilla/mailnews/mailnews.js"
 
-//@line 697 "/mozdisk/11bbuild/mozilla/mailnews/mailnews.js"
+//@line 740 "/mozdisk/112build/mozilla/mailnews/mailnews.js"
 pref("mail.empty_trash", false);
 
 pref("mail.check_new_mail", true);
@@ -703,5 +746,5 @@ pref("news.show_first_unread", false);
 pref("news.sash_geometry", "");
 pref("mail.signature_date", 0);
 
-//@line 716 "/mozdisk/11bbuild/mozilla/mailnews/mailnews.js"
+//@line 759 "/mozdisk/112build/mozilla/mailnews/mailnews.js"
 
